import logging
from PySide6.QtWidgets import QWidget, QStackedLayout, QSizePolicy
from PySide6.QtCore import Qt

from fixtracks.widgets.taskwidgets import FixTracks
from fixtracks.widgets.detectionmerge import MergeDetections
from fixtracks.widgets.taskwidget import TasksWidget
from fixtracks.widgets.converter import Json2PandasConverter

class CentralWidget(QWidget):

    def __init__(self, parent=None):
        super().__init__(parent)
        self.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Expanding)

        self._tw = TasksWidget()
        self._tw.clicked.connect(self._select_task)

        self._mergewidget = MergeDetections(self)
        self._mergewidget.back.connect(self._on_back)

        self._convertwidget = Json2PandasConverter(self)
        self._convertwidget.back.connect(self._on_back)

        self._trackwidget = FixTracks(self)

        layout = QStackedLayout()
        layout.setAlignment(Qt.AlignmentFlag.AlignCenter)
        self._tasksindex = layout.addWidget(self._tw)
        self._convertindex = layout.addWidget(self._convertwidget)
        self._mergeindex = layout.addWidget(self._mergewidget)
        self._trackindex = layout.addWidget(self._trackwidget)
        self.setLayout(layout)

    def _select_task(self, s):
        logging.debug("Centralwidget: Selected task: %s", s)
        if "merge" in s.lower():
            self.layout().setCurrentIndex(self._mergeindex)
            self._mergewidget.fileList = self._tw.fileList
        elif "tracks" in s.lower():
            self.layout().setCurrentIndex(self._trackindex)
            # self._trackwidget.fileList = self._tw.fileList
        elif "convert" in s.lower():
            self.layout().setCurrentIndex(self._convertindex)
        else:
            self.layout().setCurrentIndex(self._tasksindex)
            logging.warning("Centralwidget: got invalid task request: %s", s)

    def _on_back(self):
        self.layout().setCurrentIndex(self._tasksindex)

    # # @Slot(None)
    # def on_exit(self):
    #     self.exit_signal.emit()

    # # @Slot(None)
    # def on_new(self):
    #     self._view.setScene(self._gamescene)
