import logging
import pathlib

from PySide6.QtWidgets import QWidget, QPushButton, QFileDialog, QSizePolicy, QGridLayout
from PySide6.QtCore import Signal, Qt, QSize
from PySide6.QtGui import QIcon, QAction, QPixmap


class TasksWidget(QWidget):
    clicked = Signal((str,))

    def __init__(self, parent = None):
        super().__init__(parent)

        folderBtn = QPushButton()
        folderBtn.setEnabled(True)
        folderBtn.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Expanding)
        folderBtn.setMaximumSize(300, 300)
        folderBtn.setIcon(QIcon(":icons/open"))
        folderBtn.setIconSize(0.95 * folderBtn.size())
        folderBtn.clicked.connect(self._open_folder)

        self.convertBtn = QPushButton()
        self.convertBtn.setIcon(QIcon(":/icons/convert"))
        self.convertBtn.setToolTip("Convert JSON pose files to to Pandas data frames")
        self.convertBtn.setEnabled(True)
        self.convertBtn.setFixedSize(250, 100)
        self.convertBtn.setIconSize(0.95 * self.convertBtn.size())
        self.convertBtn.clicked.connect(self._convert_clicked)
        # self.convertBtn.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Expanding)

        self.mergeBtn = QPushButton(QIcon(":/icons/merge"), "")
        self.mergeBtn.setEnabled(False)
        self.mergeBtn.setFixedSize(250, 100)
        self.mergeBtn.setIconSize(0.95 * self.mergeBtn.size())
        self.mergeBtn.clicked.connect(self._merge_clicked)
        # self.mergeBtn.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Expanding)

        self.tracksBtn = QPushButton(QIcon(":/icons/tracks"), "")
        self.tracksBtn.setEnabled(False)
        self.tracksBtn.setFixedSize(250, 100)
        self.tracksBtn.setIconSize(0.95 * self.tracksBtn.size())
        self.tracksBtn.clicked.connect(self._tracks_clicked)
        # self.tracksBtn.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Expanding)

        l = QGridLayout()
        l.setAlignment(Qt.AlignmentFlag.AlignCenter)
        l.addWidget(folderBtn, 0, 0, 3, 1, Qt.AlignmentFlag.AlignCenter)
        l.addWidget(self.convertBtn, 0, 1, 1, 1, Qt.AlignmentFlag.AlignCenter)
        l.addWidget(self.mergeBtn, 1, 1, 1, 1, Qt.AlignmentFlag.AlignCenter)
        l.addWidget(self.tracksBtn, 2, 1, 1, 1, Qt.AlignmentFlag.AlignCenter)

        # l.addWidget(folderBtn)
        # l.addWidget(self.convertBtn)
        # l.addWidget(self.mergeBtn)
        # l.addWidget(self.tracksBtn)        
        self.setLayout(l)
        self._file_list = []

    def _merge_clicked(self):
        self.clicked.emit("Merge")

    def _tracks_clicked(self):
        self.clicked.emit("Tracks")

    def _convert_clicked(self):
        self.clicked.emit("Convert")

    def _open_folder(self):
        logging.debug("TasksWidget:select data folder")
        folder = QFileDialog.getExistingDirectory()
        if len(folder.strip()) == 0:
            logging.debug("TasksWidget: is EMPTY")
            return
        p = pathlib.Path(folder)
        logging.debug("TasksWidget: selected path is %s", p)
        for d in p.iterdir():
            if d.is_file():
                self._file_list.append(d)
        if len(self._file_list) > 0:
            self.mergeBtn.setEnabled(True)
            self.tracksBtn.setEnabled(True)

    @property
    def fileList(self):
        return self._file_list
